# geospatial

[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://gishub.org/geospatial-colab)
[![image](https://mybinder.org/badge_logo.svg)](https://gishub.org/geospatial-binder)
[![image](https://img.shields.io/pypi/v/geospatial.svg)](https://pypi.python.org/pypi/geospatial)
[![image](https://pepy.tech/badge/geospatial)](https://pepy.tech/project/geospatial)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/geospatial.svg)](https://anaconda.org/conda-forge/geospatial)
[![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/geospatial.svg)](https://anaconda.org/conda-forge/geospatial)
[![Conda Recipe](https://img.shields.io/badge/recipe-geospatial-green.svg)](https://github.com/conda-forge/geospatial-feedstock)
[![image](https://img.shields.io/badge/YouTube-Channel-red)](https://www.youtube.com/c/QiushengWu)
[![image](https://img.shields.io/twitter/follow/giswqs?style=social)](https://twitter.com/giswqs)

**A collection of Python packages for geosptial analysis and data visualization.**

-   Free software: MIT license
-   Documentation: https://geospatial.gishub.org

[![](https://i.imgur.com/A4GkBLP.png)](https://geospatial.gishub.org)

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
